==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/form-view/actions.es.js <==
Liferay.Loader.define('app-builder-web@1.0.2/js/pages/form-view/actions.es', ['module', 'exports', 'require'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.deleteDefinitionField = exports.dropLayoutBuilderField = exports.dropCustomObjectField = exports.UPDATE_PAGES = exports.UPDATE_IDS = exports.UPDATE_FOCUSED_FIELD = exports.UPDATE_FIELD_TYPES = exports.UPDATE_DATA_LAYOUT_NAME = exports.UPDATE_DATA_LAYOUT = exports.UPDATE_DATA_DEFINITION = exports.UPDATE_FOCUSED_CUSTOM_OBJECT_FIELD = exports.EVALUATION_ERROR = exports.EDIT_CUSTOM_OBJECT_FIELD = exports.DELETE_DATA_LAYOUT_FIELD = exports.DELETE_DATA_DEFINITION_FIELD = exports.ADD_CUSTOM_OBJECT_FIELD = void 0;

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var ADD_CUSTOM_OBJECT_FIELD = 'ADD_CUSTOM_OBJECT_FIELD';
  exports.ADD_CUSTOM_OBJECT_FIELD = ADD_CUSTOM_OBJECT_FIELD;
  var DELETE_DATA_DEFINITION_FIELD = 'DELETE_DATA_DEFINITION_FIELD';
  exports.DELETE_DATA_DEFINITION_FIELD = DELETE_DATA_DEFINITION_FIELD;
  var DELETE_DATA_LAYOUT_FIELD = 'DELETE_DATA_LAYOUT_FIELD';
  exports.DELETE_DATA_LAYOUT_FIELD = DELETE_DATA_LAYOUT_FIELD;
  var EDIT_CUSTOM_OBJECT_FIELD = 'EDIT_CUSTOM_OBJECT_FIELD';
  exports.EDIT_CUSTOM_OBJECT_FIELD = EDIT_CUSTOM_OBJECT_FIELD;
  var EVALUATION_ERROR = 'EVALUATION_ERROR';
  exports.EVALUATION_ERROR = EVALUATION_ERROR;
  var UPDATE_FOCUSED_CUSTOM_OBJECT_FIELD = 'UPDATE_FOCUSED_CUSTOM_OBJECT_FIELD';
  exports.UPDATE_FOCUSED_CUSTOM_OBJECT_FIELD = UPDATE_FOCUSED_CUSTOM_OBJECT_FIELD;
  var UPDATE_DATA_DEFINITION = 'UPDATE_DATA_DEFINITION';
  exports.UPDATE_DATA_DEFINITION = UPDATE_DATA_DEFINITION;
  var UPDATE_DATA_LAYOUT = 'UPDATE_DATA_LAYOUT';
  exports.UPDATE_DATA_LAYOUT = UPDATE_DATA_LAYOUT;
  var UPDATE_DATA_LAYOUT_NAME = 'UPDATE_DATA_LAYOUT_NAME';
  exports.UPDATE_DATA_LAYOUT_NAME = UPDATE_DATA_LAYOUT_NAME;
  var UPDATE_FIELD_TYPES = 'UPDATE_FIELD_TYPES';
  exports.UPDATE_FIELD_TYPES = UPDATE_FIELD_TYPES;
  var UPDATE_FOCUSED_FIELD = 'UPDATE_FOCUSED_FIELD';
  exports.UPDATE_FOCUSED_FIELD = UPDATE_FOCUSED_FIELD;
  var UPDATE_IDS = 'UPDATE_IDS';
  exports.UPDATE_IDS = UPDATE_IDS;
  var UPDATE_PAGES = 'UPDATE_PAGES';
  exports.UPDATE_PAGES = UPDATE_PAGES;

  var dropCustomObjectField = function dropCustomObjectField(_ref) {
    var dataDefinition = _ref.dataDefinition,
        dataDefinitionFieldName = _ref.dataDefinitionFieldName,
        dataLayoutBuilder = _ref.dataLayoutBuilder,
        payload = _objectWithoutProperties(_ref, ["dataDefinition", "dataDefinitionFieldName", "dataLayoutBuilder"]);

    var dataDefinitionField = dataDefinition.dataDefinitionFields.find(function (_ref2) {
      var name = _ref2.name;
      return name === dataDefinitionFieldName;
    });
    var fieldType = dataLayoutBuilder.getFieldTypes().find(function (_ref3) {
      var name = _ref3.name;
      return name === dataDefinitionField.fieldType;
    });
    var settingsContext = dataLayoutBuilder.getFieldSettingsContext(dataDefinitionField);
    var label = dataDefinitionField.label;
    return _objectSpread({}, payload, {
      fieldType: _objectSpread({}, fieldType, {
        label: label[themeDisplay.getLanguageId()],
        settingsContext: settingsContext
      })
    });
  };

  exports.dropCustomObjectField = dropCustomObjectField;

  var dropLayoutBuilderField = function dropLayoutBuilderField(_ref4) {
    var dataLayoutBuilder = _ref4.dataLayoutBuilder,
        fieldTypeName = _ref4.fieldTypeName,
        payload = _objectWithoutProperties(_ref4, ["dataLayoutBuilder", "fieldTypeName"]);

    var fieldType = dataLayoutBuilder.getFieldTypes().find(function (_ref5) {
      var name = _ref5.name;
      return name === fieldTypeName;
    });
    return _objectSpread({}, payload, {
      fieldType: _objectSpread({}, fieldType, {
        editable: true
      })
    });
  };

  exports.dropLayoutBuilderField = dropLayoutBuilderField;

  var deleteDefinitionField = function deleteDefinitionField(fieldName) {
    return {
      payload: {
        fieldName: fieldName
      },
      type: DELETE_DATA_DEFINITION_FIELD
    };
  };

  exports.deleteDefinitionField = deleteDefinitionField;
  //# sourceMappingURL=actions.es.js.map
});
//# sourceMappingURL=actions.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/form-view/actions.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/form-view/actions.es", ['module', 'exports', 'require', 'data-engine-taglib'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.deleteDefinitionField = exports.UPDATE_PAGES = exports.UPDATE_IDS = exports.UPDATE_FIELD_TYPES = exports.UPDATE_DATA_LAYOUT = exports.UPDATE_DATA_DEFINITION = exports.EVALUATION_ERROR = void 0;

  var _dataEngineTaglib = require("data-engine-taglib");

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var EVALUATION_ERROR = 'EVALUATION_ERROR';
  exports.EVALUATION_ERROR = EVALUATION_ERROR;
  var UPDATE_DATA_DEFINITION = 'UPDATE_DATA_DEFINITION';
  exports.UPDATE_DATA_DEFINITION = UPDATE_DATA_DEFINITION;
  var UPDATE_DATA_LAYOUT = 'UPDATE_DATA_LAYOUT';
  exports.UPDATE_DATA_LAYOUT = UPDATE_DATA_LAYOUT;
  var UPDATE_FIELD_TYPES = 'UPDATE_FIELD_TYPES';
  exports.UPDATE_FIELD_TYPES = UPDATE_FIELD_TYPES;
  var UPDATE_IDS = 'UPDATE_IDS';
  exports.UPDATE_IDS = UPDATE_IDS;
  var UPDATE_PAGES = 'UPDATE_PAGES';
  exports.UPDATE_PAGES = UPDATE_PAGES;

  var deleteDefinitionField = function deleteDefinitionField(fieldName) {
    return {
      payload: {
        fieldName: fieldName
      },
      type: _dataEngineTaglib.DataLayoutBuilderActions.DELETE_DATA_DEFINITION_FIELD
    };
  };

  exports.deleteDefinitionField = deleteDefinitionField;
  //# sourceMappingURL=actions.es.js.map
});
//# sourceMappingURL=actions.es.js.map
